<?php

namespace app\admin\service\order;

use app\model\Appointment;
use support\Db;
use support\Request;

class AppointmentService
{
    public static function select(Request $request)
    {
        $page = $request->get('page');
        $pageSize = $request->get('pageSize');
        $id = $request->get('id', '');
        $mobile = $request->get('mobile', '');


        $rows = Db::table('appointment')
            ->leftJoin('member', 'member.member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('goods', 'goods.goods_id', '=', 'appointment.join_appointment_goods_id')
            ->leftJoin('order', 'order.order_id', '=', 'appointment.join_appointment_order_id')
            ->leftJoin('goods_sku', 'goods_sku.goods_sku_id', '=', 'appointment.join_appointment_goods_sku_id')
            ->when($id != '', function ($query) use ($id) {
                $query->where('appointment.appointment_id', 'like', '%' . $id . '%');
            })->when($mobile != '', function ($query) use ($mobile) {
                $query->where('member.member_mobile', 'like', '%' . $mobile . '%');
            });

        $total = $rows->count('member.member_id');
        $rows = $rows->select('member.member_mobile', 'appointment.*', 'goods.goods_name', 'goods.goods_cover',
            'order.order_name', 'goods_sku.goods_sku_specs_json', 'order.order_amount_total', 'order.order_amount_pay',
            'order.order_category', 'order.order_status_system', 'order.order_status_payment', 'order.order_status_storage',
            'order.order_addtimes')
            ->orderBy('appointment.appointment_addtimes', 'desc')
            ->forPage($page, $pageSize)
            ->get();

        foreach ($rows as &$row) {
            $row->goods_cover = getenv('STORAGE_DOMAIN') . $row->goods_cover;
            $row->goods_sku_specs_json = !empty($row->goods_sku_specs_json) ? json_decode($row->goods_sku_specs_json, true) : [];
            $row->appointment_addtimes = date('Y-m-d H:i:s', $row->appointment_addtimes);
        }

        return json_success('', compact('rows', 'page', 'pageSize', 'total'));
    }

    public static function confirm($id)
    {
        $appointment = Appointment::where('appointment_id', $id)->where('appointment_status', 'WAITING')->first();
        if (!$appointment) {
            return json_fail('数据异常');
        }

        try {
            $appointment->appointment_status = 'PENDING';
            $appointment->save();

            return json_success('操作成功');
        } catch (\Exception $e) {
            dump($e->getMessage());
            return json_fail("操作失败");
        }
    }
}